snmm_fit_em: Estimate Skew-Normal Mixture parameters using Expectation...

View source: R/MixtureFitting.R

snmm_fit_emR Documentation

Estimate Skew-Normal Mixture parameters using Expectation Maximization.

Description

Estimates parameters for skew-normal mixture using Expectation Maximization algorithm.

Usage

    snmm_fit_em( x, p, w = numeric(),
                 epsilon = c( 0.000001, 0.000001, 0.000001, 0.000001 ) )

Arguments

x

data vector

p

initialization vector of 4*n parameters, where n is number of mixture components. Structure of p vector is p = c( omega1, omega2, ..., omegan, dzeta1, dzeta2, ..., dzetan, sigma1, sigma2, ..., sigman, lambda1, lambda2, ..., lambdan ), where omegai is the proportion of i-th component, dzetai is the location of i-th component, sigmai is the scale of i-th component and lambdai is the shape of i-th component.

w

weights of data points, must have the same length as the data vector; if not given or has different length, equal weights are assumed.

epsilon

tolerance threshold for convergence. Structure of epsilon is epsilon = c( epsilon_omega, epsilon_dzeta, epsilon_sigma, epsilon_lambda ), where epsilon_omega is threshold for component proportions, epsilon_dzeta is threshold for component locations, epsilon_sigma is threshold for component scales and epsilon_lambda is threshold for component shapes.

Value

Vector of mixture parameters, whose structure is the same as of input parameter's p.

Author(s)

Andrius Merkys

References

Arnold et al. The nontruncated marginal of a truncated bivariate normal distribution, Psychometrika 58, pages 471–488 (1993)

Lin et al. Finite mixture modelling using the skew normal distribution, Statistica Sinica 17 (2007), 909–927 https://www3.stat.sinica.edu.tw/statistica/oldpdf/A17n35.pdf


MixtureFitting documentation built on May 18, 2026, 5:07 p.m.