snmm_init_vector: Estimate Skew-Normal Mixture parameters using Expectation...

View source: R/MixtureFitting.R

snmm_init_vectorR Documentation

Estimate Skew-Normal Mixture parameters using Expectation Maximization.

Description

Estimate an initialization vector for skew-normal mixture fitting via Expectation Maximization. Estimation method follows Lin et al. (2007) suggestion to use k-means clustering for initial cluster assignment. Calculation of moments and dzeta and sigma parameters are done according to Equation 3 of Lin et al. (2007), but lambda is estimated from Equation 18c of Arnold et al. (1993).

Usage

    snmm_init_vector( x, n = 1 )

Arguments

x

data vector

n

number of mixture components

Value

Parameter vector of 4*n parameters, where n is number of mixture components. Structure of p vector is p = c( omega1, omega2, ..., omegan, dzeta1, dzeta2, ..., dzetan, sigma1, sigma2, ..., sigman, lambda1, lambda2, ..., lambdan ), where omegai is the proportion of i-th component, dzetai is the location of i-th component, sigmai is the scale of i-th component and lambdai is the shape of i-th component.

Author(s)

Andrius Merkys

References

Arnold et al. The nontruncated marginal of a truncated bivariate normal distribution, Psychometrika 58, pages 471–488 (1993)

Lin et al. Finite mixture modelling using the skew normal distribution, Statistica Sinica 17 (2007), 909–927 https://www3.stat.sinica.edu.tw/statistica/oldpdf/A17n35.pdf


MixtureFitting documentation built on May 18, 2026, 5:07 p.m.