View source: R/MixtureFitting.R
| llsnmm | R Documentation |
Calculates log-likelihood for a given data vector using a skew-normal mixture distribution.
llsnmm( x, p )
x |
data vector |
p |
parameter vector of 4*n parameters, where n is number of mixture components. Structure of p vector is p = c( omega1, omega2, ..., omegan, dzeta1, dzeta2, ..., dzetan, sigma1, sigma2, ..., sigman, lambda1, lambda2, ..., lambdan ), where omegai is the proportion of i-th component, dzetai is the location of i-th component, sigmai is the scale of i-th component and lambdai is the shape of i-th component. |
log-likelihood
Andrius Merkys
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.